@@ -1,10 +1,4 @@
 <?php
-/**
- * The result of the parser is an array of statements are extensions of the
- * class defined here.
- *
- * A statement represents the result of parsing the lexemes.
- */
 
 declare(strict_types=1);
 
@@ -12,6 +6,8 @@ namespace PhpMyAdmin\SqlParser;
 
 use PhpMyAdmin\SqlParser\Components\FunctionCall;
 use PhpMyAdmin\SqlParser\Components\OptionsArray;
+use Stringable;
+
 use function array_flip;
 use function array_keys;
 use function count;
@@ -20,9 +16,14 @@ use function stripos;
 use function trim;
 
 /**
+ * The result of the parser is an array of statements are extensions of the class defined here.
+ *
+ * A statement represents the result of parsing the lexemes.
+ *
  * Abstract statement definition.
  */
-abstract class Statement
+#[\AllowDynamicProperties]
+abstract class Statement implements Stringable
 {
     /**
      * Options for this statement.
@@ -41,7 +42,8 @@ abstract class Statement
      * Two options that can be used together must have different values for
      * indexes, else, when they will be used together, an error will occur.
      *
-     * @var array
+     * @var array<string, int|array<int, int|string>>
+     * @psalm-var array<string, (positive-int|array{positive-int, ('var'|'var='|'expr'|'expr=')})>
      */
     public static $OPTIONS = [];
 
@@ -55,10 +57,15 @@ abstract class Statement
      *     - 2 = 10 - add the keyword
      *     - 3 = 11 - add both the keyword and the clause
      *
-     * @var array
+     * @var array<string, array<int, int|string>>
+     * @psalm-var array<string, array{non-empty-string, (1|2|3)}>
      */
     public static $CLAUSES = [];
 
+    /**
+     * @var array<string, int|array<int, int|string>>
+     * @psalm-var array<string, (positive-int|array{positive-int, ('var'|'var='|'expr'|'expr=')})>
+     */
     public static $END_OPTIONS = [];
 
     /**
@@ -66,33 +73,35 @@ abstract class Statement
      *
      * @see static::$OPTIONS
      *
-     * @var OptionsArray
+     * @var OptionsArray|null
      */
     public $options;
 
     /**
      * The index of the first token used in this statement.
      *
-     * @var int
+     * @var int|null
      */
     public $first;
 
     /**
      * The index of the last token used in this statement.
      *
-     * @var int
+     * @var int|null
      */
     public $last;
 
     /**
-     * @param Parser     $parser the instance that requests parsing
-     * @param TokensList $list   the list of tokens to be parsed
+     * @param Parser|null     $parser the instance that requests parsing
+     * @param TokensList|null $list   the list of tokens to be parsed
      */
     public function __construct(?Parser $parser = null, ?TokensList $list = null)
     {
-        if (($parser !== null) && ($list !== null)) {
-            $this->parse($parser, $list);
+        if (($parser === null) || ($list === null)) {
+            return;
         }
+
+        $this->parse($parser, $list);
     }
 
     /**
@@ -118,15 +127,11 @@ abstract class Statement
          *
          * A clause is considered built just after fields' value
          * (`$this->field`) was used in building.
-         *
-         * @var array
          */
         $built = [];
 
         /**
          * Statement's clauses.
-         *
-         * @var array
          */
         $clauses = $this->getClauses();
 
@@ -182,9 +187,11 @@ abstract class Statement
             }
 
             // Checking if the result of the builder should be added.
-            if ($type & 1) {
-                $query = trim($query) . ' ' . $class::build($this->$field);
+            if (! ($type & 1)) {
+                continue;
             }
+
+            $query = trim($query) . ' ' . $class::build($this->$field);
         }
 
         return $query;
@@ -196,6 +203,8 @@ abstract class Statement
      * @param Parser     $parser the instance that requests parsing
      * @param TokensList $list   the list of tokens to be parsed
      *
+     * @return void
+     *
      * @throws Exceptions\ParserException
      */
     public function parse(Parser $parser, TokensList $list)
@@ -203,8 +212,6 @@ abstract class Statement
         /**
          * Array containing all list of clauses parsed.
          * This is used to check for duplicates.
-         *
-         * @var array
          */
         $parsedClauses = [];
 
@@ -215,16 +222,12 @@ abstract class Statement
          * Whether options were parsed or not.
          * For statements that do not have any options this is set to `true` by
          * default.
-         *
-         * @var bool
          */
         $parsedOptions = empty(static::$OPTIONS);
 
         for (; $list->idx < $list->count; ++$list->idx) {
             /**
              * Token parsed at this moment.
-             *
-             * @var Token
              */
             $token = $list->tokens[$list->idx];
 
@@ -243,9 +246,7 @@ abstract class Statement
             // Only keywords are relevant here. Other parts of the query are
             // processed in the functions below.
             if ($token->type !== Token::TYPE_KEYWORD) {
-                if (($token->type !== Token::TYPE_COMMENT)
-                    && ($token->type !== Token::TYPE_WHITESPACE)
-                ) {
+                if (($token->type !== Token::TYPE_COMMENT) && ($token->type !== Token::TYPE_WHITESPACE)) {
                     $parser->error('Unexpected token.', $token);
                 }
 
@@ -254,7 +255,8 @@ abstract class Statement
 
             // Unions are parsed by the parser because they represent more than
             // one statement.
-            if (($token->keyword === 'UNION') ||
+            if (
+                ($token->keyword === 'UNION') ||
                 ($token->keyword === 'UNION ALL') ||
                 ($token->keyword === 'UNION DISTINCT') ||
                 ($token->keyword === 'EXCEPT') ||
@@ -268,9 +270,7 @@ abstract class Statement
             // ON DUPLICATE KEY UPDATE ...
             // has to be parsed in parent statement (INSERT or REPLACE)
             // so look for it and break
-            if ($this instanceof Statements\SelectStatement
-                && $token->value === 'ON'
-            ) {
+            if ($this instanceof Statements\SelectStatement && $token->value === 'ON') {
                 ++$list->idx; // Skip ON
 
                 // look for ON DUPLICATE KEY UPDATE
@@ -278,7 +278,8 @@ abstract class Statement
                 $second = $list->getNextOfType(Token::TYPE_KEYWORD);
                 $third = $list->getNextOfType(Token::TYPE_KEYWORD);
 
-                if ($first && $second && $third
+                if (
+                    $first && $second && $third
                     && $first->value === 'DUPLICATE'
                     && $second->value === 'KEY'
                     && $third->value === 'UPDATE'
@@ -306,20 +307,16 @@ abstract class Statement
 
             /**
              * Parser's options.
-             *
-             * @var array
              */
             $options = [];
 
             // Looking for duplicated clauses.
-            if (! empty(Parser::$KEYWORD_PARSERS[$token->value])
+            if (
+                ! empty(Parser::$KEYWORD_PARSERS[$token->value])
                 || ! empty(Parser::$STATEMENT_PARSERS[$token->value])
             ) {
                 if (! empty($parsedClauses[$token->value])) {
-                    $parser->error(
-                        'This type of clause was previously parsed.',
-                        $token
-                    );
+                    $parser->error('This type of clause was previously parsed.', $token);
                     break;
                 }
 
@@ -330,18 +327,19 @@ abstract class Statement
             // Fix Issue #221: As `truncate` is not a keyword
             // but it might be the beginning of a statement of truncate,
             // so let the value use the keyword field for truncate type.
-            $token_value = in_array($token->keyword, ['TRUNCATE']) ? $token->keyword : $token->value;
-            if (! empty(Parser::$KEYWORD_PARSERS[$token_value]) && $list->idx < $list->count) {
-                $class = Parser::$KEYWORD_PARSERS[$token_value]['class'];
-                $field = Parser::$KEYWORD_PARSERS[$token_value]['field'];
-                if (! empty(Parser::$KEYWORD_PARSERS[$token_value]['options'])) {
-                    $options = Parser::$KEYWORD_PARSERS[$token_value]['options'];
+            $tokenValue = in_array($token->keyword, ['TRUNCATE']) ? $token->keyword : $token->value;
+            if (! empty(Parser::$KEYWORD_PARSERS[$tokenValue]) && $list->idx < $list->count) {
+                $class = Parser::$KEYWORD_PARSERS[$tokenValue]['class'];
+                $field = Parser::$KEYWORD_PARSERS[$tokenValue]['field'];
+                if (! empty(Parser::$KEYWORD_PARSERS[$tokenValue]['options'])) {
+                    $options = Parser::$KEYWORD_PARSERS[$tokenValue]['options'];
                 }
             }
 
             // Checking if this is the beginning of the statement.
             if (! empty(Parser::$STATEMENT_PARSERS[$token->keyword])) {
-                if (! empty(static::$CLAUSES) // Undefined for some statements.
+                if (
+                    ! empty(static::$CLAUSES) // Undefined for some statements.
                     && empty(static::$CLAUSES[$token->value])
                 ) {
                     // Some keywords (e.g. `SET`) may be the beginning of a
@@ -362,36 +360,26 @@ abstract class Statement
                         ++$list->idx;
                     }
 
-                    $this->options = OptionsArray::parse(
-                        $parser,
-                        $list,
-                        static::$OPTIONS
-                    );
+                    $this->options = OptionsArray::parse($parser, $list, static::$OPTIONS);
                     $parsedOptions = true;
                 }
             } elseif ($class === null) {
-                if ($this instanceof Statements\SelectStatement
+                if (
+                    $this instanceof Statements\SelectStatement
                     && ($token->value === 'FOR UPDATE'
                         || $token->value === 'LOCK IN SHARE MODE')
                 ) {
                     // Handle special end options in Select statement
                     // See Statements\SelectStatement::$END_OPTIONS
-                    $this->end_options = OptionsArray::parse(
-                        $parser,
-                        $list,
-                        static::$END_OPTIONS
-                    );
-                } elseif ($this instanceof Statements\SetStatement
+                    $this->end_options = OptionsArray::parse($parser, $list, static::$END_OPTIONS);
+                } elseif (
+                    $this instanceof Statements\SetStatement
                     && ($token->value === 'COLLATE'
                         || $token->value === 'DEFAULT')
                 ) {
                     // Handle special end options in SET statement
                     // See Statements\SetStatement::$END_OPTIONS
-                    $this->end_options = OptionsArray::parse(
-                        $parser,
-                        $list,
-                        static::$END_OPTIONS
-                    );
+                    $this->end_options = OptionsArray::parse($parser, $list, static::$END_OPTIONS);
                 } else {
                     // There is no parser for this keyword and isn't the beginning
                     // of a statement (so no options) either.
@@ -417,11 +405,11 @@ abstract class Statement
             $this->after($parser, $list, $token);
 
             // #223 Here may make a patch, if last is delimiter, back one
-            if ($class === FunctionCall::class
-                && $list->offsetGet($list->idx)->type === Token::TYPE_DELIMITER
-            ) {
-                --$list->idx;
+            if ($class !== FunctionCall::class || $list->offsetGet($list->idx)->type !== Token::TYPE_DELIMITER) {
+                continue;
             }
+
+            --$list->idx;
         }
 
         // This may be corrected by the parser.
@@ -434,6 +422,8 @@ abstract class Statement
      * @param Parser     $parser the instance that requests parsing
      * @param TokensList $list   the list of tokens to be parsed
      * @param Token      $token  the token that is being parsed
+     *
+     * @return void
      */
     public function before(Parser $parser, TokensList $list, Token $token)
     {
@@ -445,6 +435,8 @@ abstract class Statement
      * @param Parser     $parser the instance that requests parsing
      * @param TokensList $list   the list of tokens to be parsed
      * @param Token      $token  the token that is being parsed
+     *
+     * @return void
      */
     public function after(Parser $parser, TokensList $list, Token $token)
     {
@@ -453,7 +445,8 @@ abstract class Statement
     /**
      * Gets the clauses of this statement.
      *
-     * @return array
+     * @return array<string, array<int, int|string>>
+     * @psalm-return array<string, array{non-empty-string, (1|2|3)}>
      */
     public function getClauses()
     {
@@ -517,13 +510,10 @@ abstract class Statement
         $error = 0;
         $lastIdx = 0;
         foreach ($clauses as $clauseType => $index) {
-            $clauseStartIdx = Utils\Query::getClauseStartOffset(
-                $this,
-                $list,
-                $clauseType
-            );
+            $clauseStartIdx = Utils\Query::getClauseStartOffset($this, $list, $clauseType);
 
-            if ($clauseStartIdx !== -1
+            if (
+                $clauseStartIdx !== -1
                 && $this instanceof Statements\SelectStatement
                 && ($clauseType === 'FORCE'
                     || $clauseType === 'IGNORE'
@@ -550,10 +540,7 @@ abstract class Statement
             if ($clauseStartIdx !== -1 && $clauseStartIdx < $minIdx) {
                 if ($minJoin === 0 || $error === 1) {
                     $token = $list->tokens[$clauseStartIdx];
-                    $parser->error(
-                        'Unexpected ordering of clauses.',
-                        $token
-                    );
+                    $parser->error('Unexpected ordering of clauses.', $token);
 
                     return false;
                 }
