@@ -9,12 +9,10 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 
 class InsertStatementTest extends TestCase
 {
-    public function testBuilder()
+    public function testBuilder(): void
     {
         /* Assertion 1 */
-        $parser = new Parser(
-            'INSERT INTO tbl(`col1`, `col2`, `col3`) VALUES (1, "str", 3.14)'
-        );
+        $parser = new Parser('INSERT INTO tbl(`col1`, `col2`, `col3`) VALUES (1, "str", 3.14)');
         $stmt = $parser->statements[0];
         $this->assertEquals(
             'INSERT INTO tbl(`col1`, `col2`, `col3`) VALUES (1, "str", 3.14)',
@@ -23,9 +21,7 @@ class InsertStatementTest extends TestCase
 
         /* Assertion 2 */
         /* Reserved keywords (with backqoutes as field name) */
-        $parser = new Parser(
-            'INSERT INTO tbl(`order`) VALUES (1)'
-        );
+        $parser = new Parser('INSERT INTO tbl(`order`) VALUES (1)');
         $stmt = $parser->statements[0];
         $this->assertEquals(
             'INSERT INTO tbl(`order`) VALUES (1)',
@@ -34,9 +30,7 @@ class InsertStatementTest extends TestCase
 
         /* Assertion 3 */
         /* INSERT ... SET ... */
-        $parser = new Parser(
-            'INSERT INTO tbl SET FOO = 1'
-        );
+        $parser = new Parser('INSERT INTO tbl SET FOO = 1');
         $stmt = $parser->statements[0];
         $this->assertEquals(
             'INSERT INTO tbl SET FOO = 1',
@@ -45,9 +39,7 @@ class InsertStatementTest extends TestCase
 
         /* Assertion 4 */
         /* INSERT ... SELECT ... */
-        $parser = new Parser(
-            'INSERT INTO tbl SELECT * FROM bar'
-        );
+        $parser = new Parser('INSERT INTO tbl SELECT * FROM bar');
         $stmt = $parser->statements[0];
         $this->assertEquals(
             'INSERT INTO tbl SELECT * FROM bar',
@@ -56,9 +48,7 @@ class InsertStatementTest extends TestCase
 
         /* Assertion 5 */
         /* INSERT ... ON DUPLICATE KEY UPDATE ... */
-        $parser = new Parser(
-            'INSERT INTO tbl SELECT * FROM bar ON DUPLICATE KEY UPDATE baz = 1'
-        );
+        $parser = new Parser('INSERT INTO tbl SELECT * FROM bar ON DUPLICATE KEY UPDATE baz = 1');
         $stmt = $parser->statements[0];
         $this->assertEquals(
             'INSERT INTO tbl SELECT * FROM bar ON DUPLICATE KEY UPDATE baz = 1',
@@ -67,9 +57,7 @@ class InsertStatementTest extends TestCase
 
         /* Assertion 6 */
         /* INSERT [OPTIONS] INTO ... */
-        $parser = new Parser(
-            'INSERT DELAYED IGNORE INTO tbl SELECT * FROM bar'
-        );
+        $parser = new Parser('INSERT DELAYED IGNORE INTO tbl SELECT * FROM bar');
         $stmt = $parser->statements[0];
         $this->assertEquals(
             'INSERT DELAYED IGNORE INTO tbl SELECT * FROM bar',
