@@ -9,7 +9,7 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 
 class SelectStatementTest extends TestCase
 {
-    public function testBuilder()
+    public function testBuilder(): void
     {
         $query = 'SELECT * FROM t1 LEFT JOIN (t2, t3, t4) '
             . 'ON (t2.a=t1.a AND t3.b=t1.b AND t4.c=t1.c)';
@@ -22,9 +22,34 @@ class SelectStatementTest extends TestCase
             . 'ON (t2.a=t1.a AND t3.b=t1.b AND t4.c=t1.c)',
             $stmt->build()
         );
+
+        $parser = new Parser('SELECT NULL IS NULL');
+        $stmt = $parser->statements[0];
+
+        $this->assertEquals('SELECT NULL IS NULL', $stmt->build());
+
+        $parser = new Parser('SELECT NOT 1');
+        $stmt = $parser->statements[0];
+
+        $this->assertEquals('SELECT NOT 1', $stmt->build());
+
+        $parser = new Parser('SELECT 1 BETWEEN 0 AND 2');
+        $stmt = $parser->statements[0];
+
+        $this->assertEquals('SELECT 1 BETWEEN 0 AND 2', $stmt->build());
+
+        $parser = new Parser("SELECT 'a' NOT REGEXP '^[a-d]'");
+        $stmt = $parser->statements[0];
+
+        $this->assertEquals("SELECT 'a' NOT REGEXP '^[a-d]'", $stmt->build());
+
+        $parser = new Parser("SELECT 'a' RLIKE 'a'");
+        $stmt = $parser->statements[0];
+
+        $this->assertEquals("SELECT 'a' RLIKE 'a'", $stmt->build());
     }
 
-    public function testBuilderUnion()
+    public function testBuilderUnion(): void
     {
         $parser = new Parser('SELECT 1 UNION SELECT 2');
         $stmt = $parser->statements[0];
@@ -35,7 +60,35 @@ class SelectStatementTest extends TestCase
         );
     }
 
-    public function testBuilderAlias()
+    public function testBuilderWithIsNull(): void
+    {
+        $parser = new Parser('SELECT `test3`.`t1` is not null AS `is_not_null` FROM `test3` ;');
+        $stmt = $parser->statements[0];
+
+        $this->assertEquals('SELECT `test3`.`t1` is not null AS `is_not_null` FROM `test3`', $stmt->build());
+
+        $parser = new Parser('SELECT test3.t1 is null AS `col1` FROM test3');
+        $stmt = $parser->statements[0];
+
+        $this->assertEquals('SELECT test3.t1 is null AS `col1` FROM test3', $stmt->build());
+    }
+
+    public function testBuilderOrderByNull(): void
+    {
+        $query = 'SELECT * FROM some_table ORDER BY some_col IS NULL DESC;';
+        $parser = new Parser($query);
+        $stmt = $parser->statements[0];
+
+        $this->assertEquals('SELECT * FROM some_table ORDER BY some_col IS NULL DESC', $stmt->build());
+
+        $query = 'SELECT * FROM some_table ORDER BY some_col IS NOT NULL;';
+        $parser = new Parser($query);
+        $stmt = $parser->statements[0];
+
+        $this->assertEquals('SELECT * FROM some_table ORDER BY some_col IS NOT NULL ASC', $stmt->build());
+    }
+
+    public function testBuilderAlias(): void
     {
         $parser = new Parser(
             'SELECT sgu.id, sgu.email_address FROM `sf_guard_user` sgu '
@@ -54,7 +107,7 @@ class SelectStatementTest extends TestCase
         );
     }
 
-    public function testBuilderAliasOrder()
+    public function testBuilderAliasOrder(): void
     {
         $parser = new Parser(
             'SELECT sgu.id, sgu.email_address FROM `sf_guard_user` sgu '
@@ -73,7 +126,7 @@ class SelectStatementTest extends TestCase
         );
     }
 
-    public function testBuilderAliasOrderMultiple()
+    public function testBuilderAliasOrderMultiple(): void
     {
         $parser = new Parser(
             'SELECT sgu.id, sgu.email_address FROM `sf_guard_user` sgu '
@@ -92,7 +145,7 @@ class SelectStatementTest extends TestCase
         );
     }
 
-    public function testBuilderAliasOrderMultipleFunctions()
+    public function testBuilderAliasOrderMultipleFunctions(): void
     {
         $parser = new Parser(
             'SELECT sgu.id, sgu.email_address FROM `sf_guard_user` sgu '
@@ -111,7 +164,7 @@ class SelectStatementTest extends TestCase
         );
     }
 
-    public function testBuilderAliasGroupByMultipleFunctions()
+    public function testBuilderAliasGroupByMultipleFunctions(): void
     {
         $parser = new Parser(
             'SELECT sgu.id, sgu.email_address FROM `sf_guard_user` sgu '
@@ -130,7 +183,7 @@ class SelectStatementTest extends TestCase
         );
     }
 
-    public function testBuilderAliasGroupByMultipleFunctionsOrderRemoved()
+    public function testBuilderAliasGroupByMultipleFunctionsOrderRemoved(): void
     {
         $parser = new Parser(
             'SELECT sgu.id, sgu.email_address FROM `sf_guard_user` sgu '
@@ -152,7 +205,7 @@ class SelectStatementTest extends TestCase
         );
     }
 
-    public function testBuilderAliasOrderCase()
+    public function testBuilderAliasOrderCase(): void
     {
         $parser = new Parser(
             'SELECT * FROM `world_borders` ORDER BY CASE '
@@ -171,7 +224,7 @@ class SelectStatementTest extends TestCase
         );
     }
 
-    public function testBuilderAliasGroupByCase()
+    public function testBuilderAliasGroupByCase(): void
     {
         $parser = new Parser(
             'SELECT * FROM `world_borders` GROUP BY CASE '
@@ -190,7 +243,7 @@ class SelectStatementTest extends TestCase
         );
     }
 
-    public function testBuilderEndOptions()
+    public function testBuilderEndOptions(): void
     {
         /* Assertion 1 */
         $query = 'SELECT pid, name2 FROM tablename WHERE pid = 20 FOR UPDATE';
@@ -213,7 +266,7 @@ class SelectStatementTest extends TestCase
         );
     }
 
-    public function testBuilderIntoOptions()
+    public function testBuilderIntoOptions(): void
     {
         /* Assertion 1 */
         $query = 'SELECT a, b, a+b INTO OUTFILE "/tmp/result.txt"'
@@ -229,7 +282,7 @@ class SelectStatementTest extends TestCase
         );
     }
 
-    public function testBuilderGroupBy()
+    public function testBuilderGroupBy(): void
     {
         $query = 'SELECT COUNT(CustomerID), Country FROM Customers GROUP BY Country';
         $parser = new Parser($query);
@@ -241,7 +294,7 @@ class SelectStatementTest extends TestCase
         );
     }
 
-    public function testBuilderIndexHint()
+    public function testBuilderIndexHint(): void
     {
         $query = 'SELECT * FROM address FORCE INDEX (idx_fk_city_id) IGNORE KEY FOR GROUP BY (a, b,c) WHERE city_id<0';
         $parser = new Parser($query);
@@ -253,7 +306,7 @@ class SelectStatementTest extends TestCase
         );
     }
 
-    public function testBuilderSurroundedByParanthesisWithLimit()
+    public function testBuilderSurroundedByParanthesisWithLimit(): void
     {
         $query = '(SELECT first_name FROM `actor` LIMIT 1, 2)';
         $parser = new Parser($query);
