@@ -119,6 +119,7 @@ class CreateDefinitionTest extends TestCase
             . ''
             . 'ALTER TABLE `searches` ADD `admins_only` BOOLEAN NOT NULL DEFAULT FALSE AFTER `show_separators`;'
         );
+        $this->assertInstanceOf(CreateStatement::class, $parser->statements[1]);
         $this->assertEquals(
             '`public_name` varchar(120) COLLATE utf8_unicode_ci NOT NULL',
             CreateDefinition::build($parser->statements[1]->fields[2])
@@ -150,4 +151,12 @@ class CreateDefinitionTest extends TestCase
             CreateDefinition::build($parser->statements[0]->fields[0])
         );
     }
+
+    public function testBuildWithCompressed(): void
+    {
+        $query = 'CREATE TABLE `user` ( `message2` TEXT COMPRESSED )';
+        $parser = new Parser($query);
+        $stmt = $parser->statements[0];
+        $this->assertEquals("CREATE TABLE `user` (\n  `message2` text COMPRESSED\n) ", $stmt->build());
+    }
 }
