@@ -10,25 +10,39 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 
 class ExpressionTest extends TestCase
 {
-    public function testParse()
+    public function testParse(): void
     {
         $component = Expression::parse(new Parser(), $this->getTokensList('IF(film_id > 0, film_id, film_id)'));
         $this->assertEquals($component->expr, 'IF(film_id > 0, film_id, film_id)');
     }
 
-    public function testParse2()
+    public function testParse2(): void
     {
         $component = Expression::parse(new Parser(), $this->getTokensList('col`test`'));
         $this->assertEquals($component->expr, 'col');
     }
 
+    public function testParse3(): void
+    {
+        $component = Expression::parse(new Parser(), $this->getTokensList('col xx'));
+        $this->assertEquals($component->alias, 'xx');
+
+        $component = Expression::parse(new Parser(), $this->getTokensList('col y'));
+        $this->assertEquals($component->alias, 'y');
+
+        $component = Expression::parse(new Parser(), $this->getTokensList('avg.col FROM (SELECT ev.col FROM ev)'));
+        $this->assertEquals($component->table, 'avg');
+        $this->assertEquals($component->expr, 'avg.col');
+
+        $component = Expression::parse(new Parser(), $this->getTokensList('x.id FROM (SELECT a.id FROM a) x'));
+        $this->assertEquals($component->table, 'x');
+        $this->assertEquals($component->expr, 'x.id');
+    }
+
     /**
-     * @param mixed $expr
-     * @param mixed $error
-     *
      * @dataProvider parseErrProvider
      */
-    public function testParseErr($expr, $error)
+    public function testParseErr(string $expr, string $error): void
     {
         $parser = new Parser();
         Expression::parse($parser, $this->getTokensList($expr));
@@ -36,7 +50,10 @@ class ExpressionTest extends TestCase
         $this->assertEquals($errors[0][0], $error);
     }
 
-    public function parseErrProvider()
+    /**
+     * @return string[][]
+     */
+    public function parseErrProvider(): array
     {
         return [
             /*
@@ -64,7 +81,7 @@ class ExpressionTest extends TestCase
         ];
     }
 
-    public function testBuild()
+    public function testBuild(): void
     {
         $component = [
             new Expression('1 + 2', 'three'),
