@@ -9,25 +9,26 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class BugsTest extends TestCase
 {
     /**
-     * @param mixed $test
-     *
      * @dataProvider bugProvider
      */
-    public function testBug($test)
+    public function testBug(string $test): void
     {
         $this->runParserTest($test);
     }
 
-    public function bugProvider()
+    /**
+     * @return string[][]
+     */
+    public function bugProvider(): array
     {
         return [
             ['bugs/gh9'],
             ['bugs/gh14'],
             ['bugs/gh16'],
+            ['bugs/gh317'],
             ['bugs/pma11800'],
             ['bugs/pma11836'],
             ['bugs/pma11843'],
-            ['bugs/pma11867'],
             ['bugs/pma11879'],
         ];
     }
