@@ -9,16 +9,17 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class CallStatementTest extends TestCase
 {
     /**
-     * @param mixed $test
-     *
      * @dataProvider callProvider
      */
-    public function testCall($test)
+    public function testCall(string $test): void
     {
         $this->runParserTest($test);
     }
 
-    public function callProvider()
+    /**
+     * @return string[][]
+     */
+    public function callProvider(): array
     {
         return [
             ['parser/parseCall'],
