@@ -9,16 +9,17 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class CreateStatementTest extends TestCase
 {
     /**
-     * @param mixed $test
-     *
      * @dataProvider createProvider
      */
-    public function testCreate($test)
+    public function testCreate(string $test): void
     {
         $this->runParserTest($test);
     }
 
-    public function createProvider()
+    /**
+     * @return string[][]
+     */
+    public function createProvider(): array
     {
         return [
             ['parser/parseCreateDatabase'],
@@ -28,6 +29,7 @@ class CreateStatementTest extends TestCase
             ['parser/parseCreateFunctionErr2'],
             ['parser/parseCreateFunctionErr3'],
             ['parser/parseCreateProcedure'],
+            ['parser/parseCreateProcedure1'],
             ['parser/parseCreateProcedure2'],
             ['parser/parseCreateSchema'],
             ['parser/parseCreateSchemaErr'],
@@ -38,6 +40,7 @@ class CreateStatementTest extends TestCase
             ['parser/parseCreateTable5'],
             ['parser/parseCreateTable6'],
             ['parser/parseCreateTable7'],
+            ['parser/parseCreateTable8'],
             ['parser/parseCreateTableErr1'],
             ['parser/parseCreateTableErr2'],
             ['parser/parseCreateTableErr3'],
@@ -48,13 +51,22 @@ class CreateStatementTest extends TestCase
             ['parser/parseCreateTableLike'],
             ['parser/parseCreateTableSpatial'],
             ['parser/parseCreateTableTimestampWithPrecision'],
+            ['parser/parseCreateTableEnforcedCheck'],
+            ['parser/parseCreateTableNotEnforcedCheck'],
+            ['parser/parseCreateTableWithInvisibleKey'],
             ['parser/parseCreateTrigger'],
             ['parser/parseCreateUser'],
             ['parser/parseCreateView'],
             ['parser/parseCreateView2'],
+            ['parser/parseCreateView3'],
+            ['parser/parseCreateView4'],
+            ['parser/parseCreateView5'],
+            ['parser/parseCreateViewMultiple'],
             ['parser/parseCreateViewWithoutQuotes'],
             ['parser/parseCreateViewWithQuotes'],
             ['parser/parseCreateViewWithWrongSyntax'],
+            ['parser/parseCreateViewWithUnion'],
+            ['parser/parseCreateViewAsWithAs'],
         ];
     }
 }
