@@ -9,16 +9,17 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class DropStatementTest extends TestCase
 {
     /**
-     * @param mixed $test
-     *
      * @dataProvider dropProvider
      */
-    public function testDrop($test)
+    public function testDrop(string $test): void
     {
         $this->runParserTest($test);
     }
 
-    public function dropProvider()
+    /**
+     * @return string[][]
+     */
+    public function dropProvider(): array
     {
         return [
             ['parser/parseDrop'],
