@@ -9,16 +9,17 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class InsertStatementTest extends TestCase
 {
     /**
-     * @param mixed $test
-     *
      * @dataProvider insertProvider
      */
-    public function testInsert($test)
+    public function testInsert(string $test): void
     {
         $this->runParserTest($test);
     }
 
-    public function insertProvider()
+    /**
+     * @return string[][]
+     */
+    public function insertProvider(): array
     {
         return [
             ['parser/parseInsert'],
