@@ -9,7 +9,7 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 
 class LoadStatementTest extends TestCase
 {
-    public function testLoadOptions()
+    public function testLoadOptions(): void
     {
         $data = $this->getData('parser/parseLoad1');
         $parser = new Parser($data['query']);
@@ -18,16 +18,17 @@ class LoadStatementTest extends TestCase
     }
 
     /**
-     * @param mixed $test
-     *
      * @dataProvider loadProvider
      */
-    public function testLoad($test)
+    public function testLoad(string $test): void
     {
         $this->runParserTest($test);
     }
 
-    public function loadProvider()
+    /**
+     * @return string[][]
+     */
+    public function loadProvider(): array
     {
         return [
             ['parser/parseLoad1'],
