@@ -9,16 +9,17 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class PurgeStatementTest extends TestCase
 {
     /**
-     * @param mixed $test
-     *
      * @dataProvider purgeProvider
      */
-    public function testPurge($test)
+    public function testPurge(string $test): void
     {
         $this->runParserTest($test);
     }
 
-    public function purgeProvider()
+    /**
+     * @return string[][]
+     */
+    public function purgeProvider(): array
     {
         return [
             ['parser/parsePurge'],
