@@ -9,16 +9,17 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class ReplaceStatementTest extends TestCase
 {
     /**
-     * @param mixed $test
-     *
      * @dataProvider replaceProvider
      */
-    public function testReplace($test)
+    public function testReplace(string $test): void
     {
         $this->runParserTest($test);
     }
 
-    public function replaceProvider()
+    /**
+     * @return string[][]
+     */
+    public function replaceProvider(): array
     {
         return [
             ['parser/parseReplace'],
