@@ -9,16 +9,17 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class RestoreStatementTest extends TestCase
 {
     /**
-     * @param mixed $test
-     *
      * @dataProvider restoreProvider
      */
-    public function testRestore($test)
+    public function testRestore(string $test): void
     {
         $this->runParserTest($test);
     }
 
-    public function restoreProvider()
+    /**
+     * @return string[][]
+     */
+    public function restoreProvider(): array
     {
         return [
             ['parser/parseRestore'],
