@@ -9,7 +9,7 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 
 class SelectStatementTest extends TestCase
 {
-    public function testSelectOptions()
+    public function testSelectOptions(): void
     {
         $data = $this->getData('parser/parseSelect');
         $parser = new Parser($data['query']);
@@ -18,16 +18,17 @@ class SelectStatementTest extends TestCase
     }
 
     /**
-     * @param mixed $test
-     *
      * @dataProvider selectProvider
      */
-    public function testSelect($test)
+    public function testSelect(string $test): void
     {
         $this->runParserTest($test);
     }
 
-    public function selectProvider()
+    /**
+     * @return string[][]
+     */
+    public function selectProvider(): array
     {
         return [
             ['parser/parseSelect2'],
@@ -40,6 +41,9 @@ class SelectStatementTest extends TestCase
             ['parser/parseSelect9'],
             ['parser/parseSelect10'],
             ['parser/parseSelect11'],
+            ['parser/parseSelect12'],
+            ['parser/parseSelect13'],
+            ['parser/parseSelect14'],
             ['parser/parseSelectErr1'],
             ['parser/parseSelectErr2'],
             ['parser/parseSelectNested'],
@@ -82,13 +86,17 @@ class SelectStatementTest extends TestCase
             ['parser/parseSelectEndOptionsErr'],
             ['parser/parseSelectUnion'],
             ['parser/parseSelectUnion2'],
+            ['parser/parseSelectWhere'],
             ['parser/parseSelectIndexHint1'],
             ['parser/parseSelectIndexHint2'],
+            ['parser/parseSelectOrderByIsNull'],
             ['parser/parseSelectIndexHintErr1'],
             ['parser/parseSelectIndexHintErr2'],
             ['parser/parseSelectIndexHintErr3'],
             ['parser/parseSelectIndexHintErr4'],
             ['parser/parseSelectWithParenthesis'],
+            ['parser/parseSelectOrderByComment'],
+            ['parser/parseSelectOverAlias_mariadb_100600'],
         ];
     }
 }
