@@ -9,16 +9,17 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class SetStatementTest extends TestCase
 {
     /**
-     * @param mixed $test
-     *
      * @dataProvider setProvider
      */
-    public function testSet($test)
+    public function testSet(string $test): void
     {
         $this->runParserTest($test);
     }
 
-    public function setProvider()
+    /**
+     * @return string[][]
+     */
+    public function setProvider(): array
     {
         return [
             ['parser/parseSetCharset'],
