@@ -9,16 +9,17 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class TransactionStatementTest extends TestCase
 {
     /**
-     * @param mixed $test
-     *
      * @dataProvider transactionProvider
      */
-    public function testTransaction($test)
+    public function testTransaction(string $test): void
     {
         $this->runParserTest($test);
     }
 
-    public function transactionProvider()
+    /**
+     * @return string[][]
+     */
+    public function transactionProvider(): array
     {
         return [
             ['parser/parseTransaction'],
