@@ -9,16 +9,17 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 class UpdateStatementTest extends TestCase
 {
     /**
-     * @param mixed $test
-     *
      * @dataProvider updateProvider
      */
-    public function testUpdate($test)
+    public function testUpdate(string $test): void
     {
         $this->runParserTest($test);
     }
 
-    public function updateProvider()
+    /**
+     * @return string[][]
+     */
+    public function updateProvider(): array
     {
         return [
             ['parser/parseUpdate'],
