@@ -6,23 +6,31 @@ namespace PhpMyAdmin\SqlParser\Tests\Utils;
 
 use PhpMyAdmin\SqlParser\Tests\TestCase;
 use PhpMyAdmin\SqlParser\Utils\CLI;
+
 use function dirname;
 use function exec;
+
 use const PHP_BINARY;
 
 class CLITest extends TestCase
 {
-    private function getCLI($getopt)
+    /**
+     * @param array<string, bool|string>|false $getopt
+     */
+    private function getCLI($getopt): CLI
     {
-        $cli = $this->getMockBuilder('PhpMyAdmin\SqlParser\Utils\CLI')->setMethods(['getopt'])->getMock();
+        $cli = $this->createPartialMock(CLI::class, ['getopt']);
         $cli->method('getopt')->willReturn($getopt);
 
         return $cli;
     }
 
-    private function getCLIStdIn($input, $getopt)
+    /**
+     * @param array<string, bool|string>|false $getopt
+     */
+    private function getCLIStdIn(string $input, $getopt): CLI
     {
-        $cli = $this->getMockBuilder('PhpMyAdmin\SqlParser\Utils\CLI')->setMethods(['getopt', 'readStdin'])->getMock();
+        $cli = $this->createPartialMock(CLI::class, ['getopt', 'readStdin']);
         $cli->method('getopt')->willReturn($getopt);
         $cli->method('readStdin')->willReturn($input);
 
@@ -34,7 +42,7 @@ class CLITest extends TestCase
      *
      * We do mock it for other tests to return values we want.
      */
-    public function testGetopt()
+    public function testGetopt(): void
     {
         $cli = new CLI();
         $this->assertEquals(
@@ -44,20 +52,22 @@ class CLITest extends TestCase
     }
 
     /**
-     * @param mixed $getopt
-     * @param mixed $output
-     * @param mixed $result
+     * @param array<string, bool|string>|false $getopt
      *
-     * @dataProvider highlightParams
+     * @dataProvider highlightParamsProvider
      */
-    public function testRunHighlight($getopt, $output, $result)
+    public function testRunHighlight($getopt, string $output, int $result): void
     {
         $cli = $this->getCLI($getopt);
         $this->expectOutputString($output);
         $this->assertEquals($result, $cli->runHighlight());
     }
 
-    public function highlightParams()
+    /**
+     * @return array<int, array<int, int|string|array<string, bool|string>|false>>
+     * @psalm-return list<array{(array<string, bool|string>|false), string, int}>
+     */
+    public function highlightParamsProvider(): array
     {
         return [
             [
@@ -117,21 +127,22 @@ class CLITest extends TestCase
     }
 
     /**
-     * @param mixed $input
-     * @param mixed $getopt
-     * @param mixed $output
-     * @param mixed $result
+     * @param array<string, bool|string>|false $getopt
      *
-     * @dataProvider highlightParamsStdIn
+     * @dataProvider highlightParamsStdInProvider
      */
-    public function testRunHighlightStdIn($input, $getopt, $output, $result)
+    public function testRunHighlightStdIn(string $input, $getopt, string $output, int $result): void
     {
         $cli = $this->getCLIStdIn($input, $getopt);
         $this->expectOutputString($output);
         $this->assertEquals($result, $cli->runHighlight());
     }
 
-    public function highlightParamsStdIn()
+    /**
+     * @return array<int, array<int, int|string|array<string, bool|string>|false>>
+     * @psalm-return list<array{string, (array<string, bool|string>|false), string, int}>
+     */
+    public function highlightParamsStdInProvider(): array
     {
         return [
             [
@@ -184,21 +195,22 @@ class CLITest extends TestCase
     }
 
     /**
-     * @param mixed $input
-     * @param mixed $getopt
-     * @param mixed $output
-     * @param mixed $result
+     * @param array<string, bool|string>|false $getopt
      *
-     * @dataProvider lintParamsStdIn
+     * @dataProvider lintParamsStdInProvider
      */
-    public function testRunLintFromStdIn($input, $getopt, $output, $result)
+    public function testRunLintFromStdIn(string $input, $getopt, string $output, int $result): void
     {
         $cli = $this->getCLIStdIn($input, $getopt);
         $this->expectOutputString($output);
         $this->assertEquals($result, $cli->runLint());
     }
 
-    public function lintParamsStdIn()
+    /**
+     * @return array<int, array<int, int|string|array<string, bool|string>|false>>
+     * @psalm-return list<array{string, (array<string, bool|string>|false), string, int}>
+     */
+    public function lintParamsStdInProvider(): array
     {
         return [
             [
@@ -248,20 +260,22 @@ class CLITest extends TestCase
     }
 
     /**
-     * @param mixed $getopt
-     * @param mixed $output
-     * @param mixed $result
+     * @param array<string, bool|string>|false $getopt
      *
-     * @dataProvider lintParams
+     * @dataProvider lintParamsProvider
      */
-    public function testRunLint($getopt, $output, $result)
+    public function testRunLint($getopt, string $output, int $result): void
     {
         $cli = $this->getCLI($getopt);
         $this->expectOutputString($output);
         $this->assertEquals($result, $cli->runLint());
     }
 
-    public function lintParams()
+    /**
+     * @return array<int, array<int, int|string|array<string, bool|string>|false>>
+     * @psalm-return list<array{(array<string, bool|string>|false), string, int}>
+     */
+    public function lintParamsProvider(): array
     {
         return [
             [
@@ -313,20 +327,22 @@ class CLITest extends TestCase
     }
 
     /**
-     * @param mixed $getopt
-     * @param mixed $output
-     * @param mixed $result
+     * @param array<string, bool|string>|false $getopt
      *
-     * @dataProvider tokenizeParams
+     * @dataProvider tokenizeParamsProvider
      */
-    public function testRunTokenize($getopt, $output, $result)
+    public function testRunTokenize($getopt, string $output, int $result): void
     {
         $cli = $this->getCLI($getopt);
         $this->expectOutputString($output);
         $this->assertEquals($result, $cli->runTokenize());
     }
 
-    public function tokenizeParams()
+    /**
+     * @return array<int, array<int, int|string|array<string, bool|string>|false>>
+     * @psalm-return list<array{(array<string, bool|string>|false), string, int}>
+     */
+    public function tokenizeParamsProvider(): array
     {
         $result = "[TOKEN 0]\nType = 1\nFlags = 3\nValue = 'SELECT'\nToken = 'SELECT'\n\n"
             . "[TOKEN 1]\nType = 3\nFlags = 0\nValue = ' '\nToken = ' '\n\n"
@@ -366,21 +382,22 @@ class CLITest extends TestCase
     }
 
     /**
-     * @param mixed $input
-     * @param mixed $getopt
-     * @param mixed $output
-     * @param mixed $result
+     * @param array<string, bool|string>|false $getopt
      *
-     * @dataProvider tokenizeParamsStdIn
+     * @dataProvider tokenizeParamsStdInProvider
      */
-    public function testRunTokenizeStdIn($input, $getopt, $output, $result)
+    public function testRunTokenizeStdIn(string $input, $getopt, string $output, int $result): void
     {
         $cli = $this->getCLIStdIn($input, $getopt);
         $this->expectOutputString($output);
         $this->assertEquals($result, $cli->runTokenize());
     }
 
-    public function tokenizeParamsStdIn()
+    /**
+     * @return array<int, array<int, int|string|array<string, bool|string>|false>>
+     * @psalm-return list<array{string, (array<string, bool|string>|false), string, int}>
+     */
+    public function tokenizeParamsStdInProvider(): array
     {
         $result = "[TOKEN 0]\nType = 1\nFlags = 3\nValue = 'SELECT'\nToken = 'SELECT'\n\n"
             . "[TOKEN 1]\nType = 3\nFlags = 0\nValue = ' '\nToken = ' '\n\n"
@@ -419,18 +436,19 @@ class CLITest extends TestCase
     }
 
     /**
-     * @param string $cmd
-     * @param int    $result
-     *
-     * @dataProvider stdinParams
+     * @dataProvider stdinParamsProvider
      */
-    public function testStdinPipe($cmd, $result)
+    public function testStdinPipe(string $cmd, int $result): void
     {
         exec($cmd, $out, $ret);
         $this->assertSame($result, $ret);
     }
 
-    public function stdinParams()
+    /**
+     * @return array<int, array<int, int|string>>
+     * @psalm-return list<array{string, int}>
+     */
+    public function stdinParamsProvider(): array
     {
         $binPath = PHP_BINARY . ' ' . dirname(__DIR__, 2) . '/bin/';
 
