@@ -7,26 +7,31 @@ namespace PhpMyAdmin\SqlParser\Tests\Utils;
 use PhpMyAdmin\SqlParser\Parser;
 use PhpMyAdmin\SqlParser\Tests\TestCase;
 use PhpMyAdmin\SqlParser\Utils\Query;
+
 use function array_merge;
 
+/**
+ * @psalm-import-type QueryFlagsType from Query
+ */
 class QueryTest extends TestCase
 {
     /**
-     * @param mixed $query
-     * @param mixed $expected
+     * @param array<string, bool|string> $expected
+     * @psalm-param QueryFlagsType $expected
      *
      * @dataProvider getFlagsProvider
      */
-    public function testGetFlags($query, $expected)
+    public function testGetFlags(string $query, array $expected): void
     {
         $parser = new Parser($query);
-        $this->assertEquals(
-            $expected,
-            Query::getFlags($parser->statements[0])
-        );
+        $this->assertEquals($expected, Query::getFlags($parser->statements[0]));
     }
 
-    public function getFlagsProvider()
+    /**
+     * @return array<int, array<int, string|array<string, bool|string>>>
+     * @psalm-return list<array{non-empty-string, QueryFlagsType}>
+     */
+    public function getFlagsProvider(): array
     {
         return [
             [
@@ -273,7 +278,7 @@ class QueryTest extends TestCase
         ];
     }
 
-    public function testGetAll()
+    public function testGetAll(): void
     {
         $this->assertEquals(
             [
@@ -394,12 +399,11 @@ class QueryTest extends TestCase
     }
 
     /**
-     * @param mixed $query
-     * @param mixed $expected
+     * @param string[] $expected
      *
      * @dataProvider getTablesProvider
      */
-    public function testGetTables($query, $expected)
+    public function testGetTables(string $query, array $expected): void
     {
         $parser = new Parser($query);
         $this->assertEquals(
@@ -408,7 +412,11 @@ class QueryTest extends TestCase
         );
     }
 
-    public function getTablesProvider()
+    /**
+     * @return array<int, array<int, string|string[]>>
+     * @psalm-return list<array{string, string[]}>
+     */
+    public function getTablesProvider(): array
     {
         return [
             [
@@ -460,7 +468,7 @@ class QueryTest extends TestCase
         ];
     }
 
-    public function testGetClause()
+    public function testGetClause(): void
     {
         /* Assertion 1 */
         $parser = new Parser(
@@ -566,7 +574,7 @@ class QueryTest extends TestCase
         );
     }
 
-    public function testReplaceClause()
+    public function testReplaceClause(): void
     {
         $parser = new Parser('SELECT *, (SELECT 1) FROM film LIMIT 0, 10;');
         $this->assertEquals(
@@ -594,7 +602,7 @@ class QueryTest extends TestCase
         );
     }
 
-    public function testReplaceClauseOnlyKeyword()
+    public function testReplaceClauseOnlyKeyword(): void
     {
         $parser = new Parser('SELECT *, (SELECT 1) FROM film LIMIT 0, 10');
         $this->assertEquals(
@@ -609,7 +617,7 @@ class QueryTest extends TestCase
         );
     }
 
-    public function testReplaceNonExistingPart()
+    public function testReplaceNonExistingPart(): void
     {
         $parser = new Parser('ALTER TABLE `sale_mast` OPTIMIZE PARTITION p3');
         $this->assertEquals(
@@ -623,11 +631,10 @@ class QueryTest extends TestCase
         );
     }
 
-    public function testReplaceClauses()
+    public function testReplaceClauses(): void
     {
-        $this->assertEquals('', Query::replaceClauses(null, null, []));
-
         $parser = new Parser('SELECT *, (SELECT 1) FROM film LIMIT 0, 10;');
+        $this->assertSame('', Query::replaceClauses($parser->statements[0], $parser->list, []));
         $this->assertEquals(
             'SELECT *, (SELECT 1) FROM film WHERE film_id > 0 LIMIT 0, 10',
             Query::replaceClauses(
@@ -677,7 +684,7 @@ class QueryTest extends TestCase
         );
     }
 
-    public function testGetFirstStatement()
+    public function testGetFirstStatement(): void
     {
         $query = 'USE saki';
         $delimiter = null;
